@@ -36,6 +36,12 @@ def xlinkns():
     return "http://www.w3.org/1999/xlink"
 
 
+def strip_ns(tagname):
+    if "}" in tagname:
+        return tagname[tagname.index("}") + 1 :]
+    return tagname
+
+
 # https://www.w3.org/TR/SVG11/paths.html#PathData
 _CMD_ARGS = {
     "m": 2,
@@ -100,6 +106,10 @@ def ntos(n: float) -> str:
     return str(int(n)) if isinstance(n, float) and n.is_integer() else str(n)
 
 
+def number_or_percentage(s: str, scale=1) -> float:
+    return float(s[:-1]) / 100 * scale if s.endswith("%") else float(s)
+
+
 def path_segment(cmd, *args):
     # put commas between coords, spaces otherwise, author readability pref
     args_per_cmd = check_cmd(cmd, args)
@@ -125,7 +135,7 @@ def parse_css_declarations(
     output: MutableMapping[str, Any],
     property_names: Optional[Container[str]] = None,
 ) -> str:
-    """ Parse CSS declaration list into {property: value} dict.
+    """Parse CSS declaration list into {property: value} dict.
 
     Args:
         style: CSS declaration list without the enclosing braces,
